@@ -1,10 +1,15 @@
 package Net::SSH::Perl::WithSocks;
 use strict;
 use warnings;
-use base qw(Net::SSH::Perl);
-use vars qw($VERSION);
+use parent qw(Net::SSH::Perl);
 
-$VERSION = '0.02';
+require v5.10; # Dependency Math-GMP-2.15 requires 5.10
+               # Todo investigate if the module is required
+               # and if we could use older or change module
+
+our $VERSION = '0.023';
+
+=encoding utf8
 
 =head1 NAME
 
@@ -86,12 +91,19 @@ off basic one-off hops and requests.
 
 =head1 AUTHOR
 
-Jennie Rose Evers-Corvina C<< <seven@nanabox.net> >>, Matthew S Trout
+Jennie Rose Evers-Corvina C<< <seven@nanabox.net> >>,
+Matt S. Trout (mst) C<< <mst@shadowcat.co.uk> >>
+
+=head1 SOURCE AVAILABILITY
+
+This project is in GitHub:
+
+	https://github.com/briandfoy/net-ssh-perl-withsocks
 
 =head1 COPYRIGHT
 
 =head1 LICENSE
 
-You can use this package under the same terms as Perl itself.
+You can use this package under the Artistic License 2.0.
 
 =cut
